.. _ovn_tutorial:

==========================
OpenStack and OVN Tutorial
==========================

The OVN project documentation includes an in depth tutorial of using OVN with
OpenStack.

`OpenStack and OVN Tutorial <https://docs.ovn.org/en/latest/tutorials/ovn-openstack.html>`_
